@@ -379,3 +379,12 @@ class Datastore(object):
         transaction = self.beginTransaction(session=session)
         mutation = self.make_mutation(operation, key, properties=properties)
         self.commit([mutation], transaction=transaction, session=session)
+
+    def close(self):
+        self.session.close()
+
+    def __enter__(self)               :
+        return self
+
+    def __exit__(self, *args)        :
+        self.close()
